# -*- coding: UTF-8 -*-
# Copyright 2016-2023 Rumma & Ko Ltd
# License: GNU Affero General Public License v3 (see file COPYING for details)

from lino.projects.std.settings import *
from lino_cms import SETUP_INFO

class Site(Site):

    verbose_name = "Lino CMS"
    description = SETUP_INFO['description']
    version = SETUP_INFO['version']
    url = SETUP_INFO['url']

    demo_fixtures = ['std', 'demo', 'demo2', 'checkdata']
    user_types_module = 'lino_cms.lib.cms.user_types'
    custom_layouts_module = 'lino_cms.lib.cms.layouts'
    migration_class = 'lino_cms.lib.cms.migrate.Migrator'
    default_ui = "lino_react.react"

    def setup_features(self):
        super().setup_features()
        self.enable_feature('third_party_authentication')

    def get_installed_apps(self):
        """Implements :meth:`lino.core.site.Site.get_installed_apps`.

        """
        yield super(Site, self).get_installed_apps()
        yield 'lino_cms.lib.cms'
        yield 'lino_cms.lib.users'
        yield 'lino_xl.lib.contacts'
        # yield 'lino_cms.lib.cal'
        # yield 'lino_xl.lib.calview'
        yield 'lino_xl.lib.pages'
        yield 'lino_xl.lib.blogs'
        yield 'lino_xl.lib.albums'
        yield 'lino.modlib.comments'
        # yield 'lino.modlib.uploads'
        yield 'lino.modlib.help'
        yield 'lino.modlib.publisher'
        yield 'lino.modlib.checkdata'  # fill body_preview during prep

    # def setup_quicklinks(self, ut, tb):
    #     super(Site, self).setup_quicklinks(ut, tb)

    def get_plugin_configs(self):
        yield super().get_plugin_configs()
        # yield ('system', 'use_dashboard_layouts', True)
        yield ('users', 'allow_online_registration', True)
        # yield ('cal', 'with_demo_appointments', False)
        yield ('help', 'make_help_pages', True)
        yield ('help', 'use_contacts', True)
        yield ('help', 'include_useless', True)
        yield ('memo', 'short_preview_length', 600)

from lino.core.auth.utils import activate_social_auth_testing
activate_social_auth_testing(globals())



# -*- coding: UTF-8 -*-
# Copyright 2013-2021 Rumma & Ko Ltd
# License: GNU Affero General Public License v3 (see file COPYING for details)

"""Extends :mod:`lino_xl.lib.cal` for cms.

"""


from lino_xl.lib.cal import Plugin


class Plugin(Plugin):

    extends_models = ['Event', 'Room']



# -*- coding: UTF-8 -*-
# Copyright 2016-2022 Rumma & Ko Ltd
# License: GNU Affero General Public License v3 (see file COPYING for details)

from lino.modlib.users import Plugin


class Plugin(Plugin):

    extends_models = ['User']



"""
Examples how to run these tests::

  $ python setup.py test
  $ python setup.py test -s tests.DocsTests
  $ python setup.py test -s tests.DocsTests.test_debts
  $ python setup.py test -s tests.DocsTests.test_docs
"""
from unipath import Path

ROOTDIR = Path(__file__).parent.parent

SETUP_INFO = {}

# load SETUP_INFO:
filename = ROOTDIR.child('lino_cms', 'setup_info.py')
exec(compile(open(filename, "rb").read(), filename, 'exec'))

from lino.utils.pythontest import TestCase

import os
#os.environ['DJANGO_SETTINGS_MODULE'] = "lino_cms.settings.test"


# class BaseTestCase(TestCase):
#     project_root = ROOTDIR
#     django_settings_module = 'lino_noi.settings.test'


class PackagesTests(TestCase):

    def test_packages(self):
        self.run_packages_test(SETUP_INFO['packages'])


class SpecsTests(TestCase):

    def test_general(self):
        self.run_simple_doctests('docs/specs/general.rst')

    def test_db(self):
        self.run_simple_doctests('docs/specs/db.rst')

    def test_roles(self):
        self.run_simple_doctests('docs/specs/roles.rst')


class DemoTests(TestCase):
    """Run tests on the demo projects.
    """

    def test_cms(self):
        self.run_django_manage_test('lino_cms/projects/cms')




# -*- coding: UTF-8 -*-
# Copyright 2016-2022 Rumma & Ko Ltd
# License: GNU Affero General Public License v3 (see file COPYING for details)

"""Default data migrator for Lino Cms.


"""

from django.conf import settings
from lino.api import dd, rt
from lino.utils.dpy import Migrator, override

class Migrator(Migrator):
    """The standard migrator for Lino Cms.

    This is used because
    :class:`lino_cms.projects.cms.settings.Site` has
    :attr:`migration_class <lino.core.site.Site.migration_class>` set
    to ``"lino_cms.lib.cms.migrate.Migrator"``.

    """
    def migrate_from_0_0_1(self, globals_dict):
        # do something here
        return '0.0.2'




# -*- coding: UTF-8 -*-
# Copyright 2016-2022 Rumma & Ko Ltd
# License: GNU Affero General Public License v3 (see file COPYING for details)

"""Plugins for Lino Cms.

.. autosummary::
   :toctree:

    cms
    users

"""



# -*- coding: UTF-8 -*-
# Copyright 2016-2022 Rumma & Ko Ltd
# License: GNU Affero General Public License v3 (see file COPYING for details)

from lino.api import dd, _
from lino.modlib.users.ui import *

class UserDetail(UserDetail):

    main = "general contact"

    general = dd.Panel("""
    box1
    remarks:40 users.AuthoritiesGiven:20
    """, label=_("General"))

    box1 = """
    username user_type:20
    language time_zone
    id created modified
    """

    contact = dd.Panel("""
    first_name last_name initials
    """, label=_("Contact"))

Users.detail_layout = UserDetail()

Users.column_names = "first_name email"



# -*- coding: UTF-8 -*-
# Copyright 2016-2022 Rumma & Ko Ltd
# License: GNU Affero General Public License v3 (see file COPYING for details)

from lino.api import dd, _
from lino.modlib.users.models import *


class User(User):

    class Meta(User.Meta):
        abstract = dd.is_abstract_model(__name__, 'User')


from .ui import *



# python setup.py test -s tests/test_packages.py

from lino_cms import SETUP_INFO
from lino.utils.pythontest import TestCase

class PackagesTests(TestCase):

    def test_packages(self):
        self.run_packages_test(SETUP_INFO['packages'])



# -*- coding: UTF-8 -*-
# generated by lino.sphinxcontrib.help_text_builder
from django.utils.translation import gettext_lazy as _

help_texts = {
    'lino_cms.lib.cms.migrate.Migrator' : _("""The standard migrator for Lino Cms."""),
    'lino_cms.lib.cms.user_types.EndUser' : _("""An end user is somebody who uses our database, but won’t work
on it."""),
    'lino_cms.lib.cms.user_types.Admin' : _("""Can do everything."""),
}



# -*- coding: UTF-8 -*-
# Copyright 2017-2023 Rumma & Ko Ltd
# License: GNU Affero General Public License v3 (see file COPYING for details)

"""Defines the user types for a Lino CMS.

"""

from lino.core.roles import UserRole, SiteAdmin, SiteStaff, SiteUser
from lino_xl.lib.blogs.roles import BlogsReader
from lino_xl.lib.cal.roles import CalendarReader
from lino.modlib.checkdata.roles import CheckdataUser
from lino.modlib.search.roles import SiteSearcher
from lino.modlib.office.roles import OfficeUser, OfficeStaff, OfficeOperator
from lino.modlib.uploads.roles import UploadsReader
from lino.modlib.comments.roles import CommentsUser, CommentsStaff, CommentsReader

from lino.modlib.users.choicelists import UserTypes
from django.utils.translation import gettext_lazy as _


class EndUser(BlogsReader, SiteUser, CheckdataUser, CommentsUser,
    OfficeUser, CommentsReader, CalendarReader):
    """An **end user** is somebody who uses our database, but won't work
    on it.

    """
    pass


class Staff(SiteStaff, EndUser, CommentsStaff, OfficeOperator):
    pass


class Admin(SiteAdmin, Staff, OfficeStaff):
    """Can do everything."""


# class Anonymous(CommentsReader, CalendarReader):
class Anonymous(SiteSearcher, BlogsReader, CalendarReader, UploadsReader):
    pass

UserTypes.clear()
add = UserTypes.add_item
add('000', _("Anonymous"),        Anonymous, 'anonymous',
    readonly=True, authenticated=False)
add('100', _("User"),             EndUser, 'user')
add('800', _("Staff"),            Staff, 'staff')
add('900', _("Administrator"),    Admin, 'admin')



# -*- coding: UTF-8 -*-
# Copyright 2021 Rumma & Ko Ltd
# License: GNU Affero General Public License v3 (see file COPYING for details)

from lino.modlib.system.choicelists import DashboardLayouts
from lino.api import _

DashboardLayouts.clear()
add = DashboardLayouts.add_item
add("default", _("Default dashboard"), """
welcome_messages
pages.PublicNodes
blogs.LatestEntries
""")



# -*- coding: UTF-8 -*-
# Copyright 2011-2016 Rumma & Ko Ltd
# License: GNU Affero General Public License v3 (see file COPYING for details)

import datetime

from lino.api import dd, rt, _

from lino_xl.lib.cal.fixtures.std import objects as lib_objects


def objects():

    yield lib_objects()

    GuestRole = rt.models.cal.GuestRole

    yield GuestRole(**dd.str2kw('name', _("Participant")))
    yield GuestRole(**dd.str2kw('name', _("Guide")))
    yield GuestRole(**dd.str2kw('name', _("Teacher")))

    EventType = rt.models.cal.EventType
    RecurrentEvent = rt.models.cal.RecurrentEvent
    Recurrencies = rt.models.cal.Recurrencies
    DEMO_START_YEAR = rt.models.cal.DEMO_START_YEAR

    holidays = EventType.objects.get(
        **dd.str2kw('name', _("Holidays")))
    yield RecurrentEvent(
        event_type=holidays,
        every_unit=Recurrencies.yearly,
        monday=True, tuesday=True, wednesday=True, thursday=True,
        friday=True, saturday=True, sunday=True,
        every=1,
        start_date=datetime.date(
            year=DEMO_START_YEAR,
            month=7, day=1),
        end_date=datetime.date(
            year=DEMO_START_YEAR,
            month=8, day=31),
        **dd.str2kw('name', _("Summer holidays")))



from atelier.invlib import setup_from_tasks
ns = setup_from_tasks(
    globals(), "lino_cms",
    languages="en de fr".split(),
    # tolerate_sphinx_warnings=True,
    locale_dir='lino_cms/lib/cms/locale',
    revision_control_system='git',
    cleanable_files=['docs/api/lino_cms.*'])



# -*- coding: UTF-8 -*-
# Copyright 2022-2023 Rumma & Ko Ltd
# License: GNU Affero General Public License v3 (see file COPYING for details)

# Some content of this file is explicitly modified by `getlino startproject`.
# Please check for consistency with getlino.startproject.py file before you
# modify anything.

SETUP_INFO = dict(
    name='lino-cms',
    version='23.10.0',
    install_requires=['lino-xl'],
    description=('Manage the content of your website'),
    long_description="""\

**Lino CMS** is a Content Management System à la Lino.

- Source code: https://gitlab.com/lino-framework/cms

- Documentation: https://lino-framework.gitlab.io/cms/

- This project is part of the Lino framework, which is documented
  at https://www.lino-framework.org

- Changelog: https://lino-framework.gitlab.io/cms/changes.html

- For introductions, commercial information and hosting solutions
  see https://www.saffre-rumma.net

- This is a sustainably free open-source project. Your contributions are
  welcome.  See https://community.lino-framework.org for details.


""",
    author='Rumma & Ko Ltd',
    author_email='info@lino-framework.org',
    url="https://gitlab.com/lino-framework/cms",
    license_files=['COPYING'],
    test_suite='tests')

SETUP_INFO.update(classifiers="""
Programming Language :: Python
Programming Language :: Python :: 3
Development Status :: 1 - Planning
Environment :: Web Environment
Framework :: Django
Intended Audience :: Developers
Intended Audience :: System Administrators
License :: OSI Approved :: GNU Affero General Public License v3
Operating System :: OS Independent
Topic :: Database :: Front-Ends
Topic :: Office/Business
Topic :: Software Development :: Libraries :: Application Frameworks
""".format(**SETUP_INFO).strip().splitlines())
SETUP_INFO.update(packages=[
    'lino_cms',
    'lino_cms.lib',
    'lino_cms.lib.cal',
    'lino_cms.lib.cal.fixtures',
    'lino_cms.lib.cms',
    'lino_cms.lib.users',
    'lino_cms.lib.users.fixtures',
])

SETUP_INFO.update(message_extractors={
    'lino_cms': [
        ('**/cache/**', 'ignore', None),
        ('**.py', 'python', None),
        ('**.js', 'javascript', None),
        ('**/config/**.html', 'jinja2', None),
    ],
})

SETUP_INFO.update(include_package_data=True)

# SETUP_INFO.update(package_data=dict())
#
# def add_package_data(package, *patterns):
#     l = SETUP_INFO['package_data'].setdefault(package, [])
#     l.extend(patterns)
#     return l
#
# l = add_package_data('lino_cms.lib.cms')
# for lng in 'de fr'.split():
#     l.append('lino_cms/lib/cms/locale/%s/LC_MESSAGES/*.mo' % lng)



# -*- coding: UTF-8 -*-
# Copyright 2013-2022 Rumma & Ko Ltd
# License: GNU Affero General Public License v3 (see file COPYING for details)


from django.utils.translation import gettext_lazy as _

from lino.modlib.users.choicelists import UserTypes
from lino.modlib.office.roles import OfficeUser
from lino.modlib.publisher.mixins import Publishable
from lino.modlib.publisher.choicelists import PublisherViews
from lino.modlib.memo.mixins import BabelPreviewable
from lino_xl.lib.cal.models import *
from lino_xl.lib.courses.choicelists import EnrolmentStates



class Room(Room, Publishable, BabelPreviewable):

    class Meta(Room.Meta):
        abstract = dd.is_abstract_model(__name__, 'Room')


class Rooms(Rooms):
    column_names = "name company company__city *"
    detail_layout = """
    id name
    company contact_person contact_role
    cal.EntriesByRoom
    """

PublisherViews.add_item_lazy("rooms", Rooms)


class Event(Event, Publishable, BabelPreviewable):

    class Meta(Event.Meta):
        abstract = dd.is_abstract_model(__name__, 'Event')


class MyEntries(MyEntries):
    column_names = 'when_text detail_link #summary room owner workflow_buttons *'
